@@ -2,7 +2,7 @@
 #
 # MANAGESIEVE (timsieved) client script
 #
-# Copyright © 2006-2016 Phil Pennock.  All rights reserved.
+# Copyright © 2006-2018 Phil Pennock.  All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -92,7 +92,7 @@ my $OPENSSL_COMMAND = 'openssl';
 # ######################################################################
 # No user-serviceable parts below
 
-our $VERSION = '0.89';
+our $VERSION = '0.90';
 
 use Authen::SASL 2.11 qw(Perl);
 # 2.11: first version with non-broken DIGEST-MD5
@@ -927,7 +927,7 @@ if (defined $realm) {
 		if (/^"(.*)"\r?\n?$/) {
 			$challenge = $1;
 		} else {
-			unless (/^{(\d+)\+?}\r?$/m) {
+			unless (/^\{(\d+)\+?}\r?$/m) {
 				sfinish $sock, "*";
 				closedie($sock, "Failure to parse server SASL response.\n");
 			}
@@ -1510,7 +1510,7 @@ sub sieve_download
 		warn qq{Empty script "$remotefn"?  Not saved.\n};
 		return;
 	}
-	unless (/^{(\d+)\+?}\r?$/m) {
+	unless (/^\{(\d+)\+?}\r?$/m) {
 		die "QUIT:Failed to parse server response to GETSCRIPT";
 	}
 	my $contentdata = $_;
@@ -1526,7 +1526,7 @@ sub sieve_download
 			or die "write-open($localfn) failed: $!\n";
 		$oldouthandle = select $fh;
 	}
-	$contentdata =~ s/^{\d+\+?}\r?\n?//m;
+	$contentdata =~ s/^\{\d+\+?}\r?\n?//m;
 	print $contentdata;
 	select $oldouthandle if defined $oldouthandle;
 	if (defined $fh) {
@@ -1606,7 +1606,7 @@ sub sieve_edit
 	my ($sock, $remotefn) = @_; splice @_, 0, 2;
 	my ($rc, $key);
 
-	my ($fh,$localfn) = tempfile();
+	my ($fh,$localfn) = tempfile(SUFFIX => '.sieve');
 
 	sieve_download($sock, $remotefn, $localfn)
 		or die "failed to download script";
